import yaml
import os

class PersistentSet:

    def __init__(self, path):
        self.path = path
        self.savedSet = set()
        if os.path.exists(path):
            with open(self.path) as ymlfile:
                savedList = yaml.load(ymlfile)
                for el in savedList:
                    self.savedSet.add(el)
                    
    def save(self):
        with open(self.path, 'w') as f:
            f.write( yaml.dump( [el for el in self.savedSet]))
            
    def __len__(self):
        return len(self.savedSet)

    def __setitem__(self, key, val):
        self.savedList[key] = val
        self.save()
        
    def add(self, val):
        self.savedSet.add(val)
        self.save()

    def __delitem__(self, key):
        assert False

    def __contains__(self, key):
        return key in self.savedSet

    def __iter__(self):
        return iter(self.savedSet)



import yaml
import os

class PersistentDict:

    def __init__(self, path):
        self.path = path
        if os.path.exists(path):
            with open(self.path) as ymlfile:
                self.savedDict = yaml.load(ymlfile)
        else:
            self.savedDict = {}

    def save(self):
        with open(self.path, 'w') as f:
            f.write( yaml.dump( self.savedDict))
        
            
    def __getitem__(self, key):
        return self.savedDict[key]

    def __len__(self):
        return len(self.savedDict)

    def __setitem__(self, key, val):
        self.savedDict[key] = val
        self.save()
        
    def append(self, val):
        self.savedDict.append(val)
        self.save()

    def __delitem__(self, key):
        del self.savedDict[key]
        self.save()

    def __contains__(self, key):
        return key in self.savedDict

    def keys(self):
        return self.savedDict.keys()

    def items(self):
        return self.savedDict.items()



import setuptools

setuptools.setup(
    name="yaml_backed_structs",
    version="0.9.0",
    url="https://github.com/dcdanko/YamlBackedPyStructs",

    author="David C. Danko",
    author_email="dcdanko@gmail.com",

    description="Basic python data structures backed by a human editable yaml file",
    long_description=open('README.rst').read(),

    packages=['yaml_backed_structs'],

    install_requires=['PyYAML==3.12'],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
